DeviceManager
-------------------------------

.. automodule:: google.cloud.iot_v1.services.device_manager
    :members:
    :inherited-members:

.. automodule:: google.cloud.iot_v1.services.device_manager.pagers
    :members:
    :inherited-members:
